@@ -115,42 +115,67 @@ def plot_pulls(**kwargs):
     
     
 @click.command(name='likelihood_scan')
-@click.option('-i', '--input_file', required=True, help='Path to the input workspace file.')
-@click.option('--min', 'poi_min', type=float, required=True, help='Minimum POI value to scan.')
-@click.option('--max', 'poi_max', type=float, required=True, help='Maximum POI value to scan.')
-@click.option('--step', 'poi_step', type=float, required=True, help='Scan interval.')
-@click.option('-p', '--poi', default="", help='POI to scan. If not specified, the first POI from the workspace is used.')
-@click.option('--cache/--no-cache', default=True, help='Cache existing result')
-@click.option('-o', '--outname', default='{poi}', help='Name of output.')
-@click.option('--outdir', default='likelihood_scan', help='Output directory.')
-@click.option('--vmin', type=float, default=10, help='Minimum range of POI relative to the central value during likelihood calculation.')
-@click.option('--vmax', type=float, default=10, help='Maximum range of POI relative to the central value during likelihood calculation.')
-@click.option('-w', '--workspace', default=None, help='Name of workspace. Auto-detect by default.')
-@click.option('-m', '--model_config', default=None, help='Name of model config. Auto-detect by default.')
-@click.option('-d', '--data', default='combData', help='Name of dataset.')
-@click.option('-s', '--snapshot', default=None, help='Name of initial snapshot')
-@click.option('-r', '--profile', default="", help='Parameters to profile')
-@click.option('-f', '--fix', default="", help='Parameters to fix')
-@click.option('--hesse/--no-hesse', default=False, help='Use Hesse error calculation')
-@click.option('--minos/--no-minos', default=True, help='Use Minos error calculation')
-@click.option('--constrain/--no-constrain', default=True, help='Use constrained NLL (i.e. include systematics)')
-@click.option('-t', '--minimizer_type', default="Minuit2", help='Minimizer type')
-@click.option('-a', '--minimizer_algo', default="Migrad", help='Minimizer algorithm')
-@click.option('-c', '--num_cpu', type=int, default=1, help='Number of CPUs to use per parameter')
-@click.option('--binned/--unbinned', default=True, help='Binned likelihood')
-@click.option('-e', '--eps', type=float, default=1.0, help='Convergence criterium')
-@click.option('--strategy', type=int, default=0, help='Default minimization strategy')
-@click.option('--print_level', type=int, default=1, help='Minimizer print level')
-@click.option('--fix-cache/--no-fix-cache', default=True, help='Fix StarMomentMorph cache')
-@click.option('--fix-multi/--no-fix-cache',  default=True, help='Fix MultiPdf level 2')
-@click.option('--mpsplit',  default=3, help='MP split mode')
-@click.option('-v', '--verbose',  default=0, help='verbosity')
-@click.option('--max_calls', type=int, default=-1, help='Maximum number of function calls')
-@click.option('--max_iters', type=int, default=-1, help='Maximum number of Minuit iterations')
-@click.option('--optimize', type=int, default=2, help='Optimize constant terms')
-@click.option('--offset/--no-offset', default=False, help='Offset likelihood')
-@click.option('--parallel', type=int, default=-1, help='Parallelize job across different scan values.'+\
-                                                       'Use -1 for N_CPU workers.')
+@click.option('-i', '--input_file', 'filename', required=True, 
+              help='Path to the input workspace file.')
+@click.option('--min', 'poi_min', type=float, required=True, 
+              help='Minimum POI value to scan.')
+@click.option('--max', 'poi_max', type=float, required=True, 
+              help='Maximum POI value to scan.')
+@click.option('--step', 'poi_step', type=float, required=True, 
+              help='Scan interval.')
+@click.option('-p', '--poi', 'poi_name', default=None, show_default=True,
+              help='POI to scan. If not specified, the first POI from the workspace is used.')
+@click.option('--cache/--no-cache', default=True, show_default=True,
+              help='Cache existing result')
+@click.option('-o', '--outname', default='{poi_name}', show_default=True,
+              help='Name of output.')
+@click.option('--outdir', default='likelihood_scan', show_default=True,
+              help='Output directory.')
+@click.option('-w', '--workspace', 'ws_name', default=None, show_default=True,
+              help='Name of workspace. Auto-detect by default.')
+@click.option('-m', '--model_config', 'mc_name', default=None, show_default=True,
+              help='Name of model config. Auto-detect by default.')
+@click.option('-d', '--data', 'data_name', default='combData', show_default=True,
+              help='Name of dataset.')
+@click.option('-s', '--snapshot', 'snapshot_name', default=None, show_default=True,
+              help='Name of initial snapshot')
+@click.option('-r', '--profile', 'profile_param', default="", show_default=True,
+              help='Parameters to profile')
+@click.option('-f', '--fix', 'fix_param', default="", show_default=True,
+              help='Parameters to fix')
+@click.option('--constrain/--no-constrain', 'constrain_nuis', default=True, show_default=True,
+              help='Use constrained NLL (i.e. include systematics)')
+@click.option('-t', '--minimizer_type', default="Minuit2", show_default=True,
+              help='Minimizer type')
+@click.option('-a', '--minimizer_algo', default="Migrad", show_default=True,
+              help='Minimizer algorithm')
+@click.option('-c', '--num_cpu', type=int, default=1, show_default=True,
+              help='Number of CPUs to use per parameter')
+@click.option('--binned/--unbinned', 'binned_likelihood', default=True, show_default=True,
+              help='Binned likelihood')
+@click.option('-e', '--eps', type=float, default=1.0, show_default=True,
+              help='Convergence criterium')
+@click.option('--strategy', type=int, default=1, show_default=True,
+              help='Default minimization strategy')
+@click.option('--print_level', type=int, default=0, show_default=True,
+              help='Minimizer print level')
+@click.option('--fix-cache/--no-fix-cache', default=True, show_default=True,
+              help='Fix StarMomentMorph cache')
+@click.option('--fix-multi/--no-fix-cache',  default=True, show_default=True,
+              help='Fix MultiPdf level 2')
+@click.option('--max_calls', type=int, default=-1, show_default=True,
+              help='Maximum number of function calls')
+@click.option('--max_iters', type=int, default=-1, show_default=True,
+              help='Maximum number of Minuit iterations')
+@click.option('--optimize', type=int, default=2, show_default=True,
+              help='Optimize constant terms')
+@click.option('--offset/--no-offset', default=True, show_default=True,
+              help='Offset likelihood')
+@click.option('-v', '--verbosity', default="WARNING", show_default=True,
+              help='verbosity level ("DEBUG", "INFO", "WARNING", "ERROR")')
+@click.option('--parallel', type=int, default=-1, show_default=True,
+              help='Parallelize job across different scan values.'+\
+                   'Use -1 for N_CPU workers.')
 def likelihood_scan(**kwargs):
     """
     Tool for likelihood scan
@@ -159,44 +184,77 @@ def likelihood_scan(**kwargs):
     scan_nll(**kwargs)
 
 @click.command(name='cls_limit')
-@click.option('-i', '--input_file', 'filename', required=True, help='Path to the input workspace file')
-@click.option('-p', '--poi', 'poi_name', default=None, help='POI to scan. If not specified, the first POI from the workspace is used.')
-@click.option('-d', '--data', 'data_name', default='combData', help='Name of dataset')
-@click.option('-o', '--outname', default='limits.json', help='Name of output')
-@click.option('--blind/--unblind', 'do_blind', default=True, help='Blind/unblind analysis')
-@click.option('--CL', 'CL', default=0.95, help='CL value to use')
-@click.option('--precision', default=0.005, help='precision in mu that defines iterative cutoff')
-@click.option('--do_tilde/--no_tilde', default=True, help='bound mu at zero if true and do the \tilde{q}_{mu} asymptotics')
-@click.option('--predictive_fit/--no_predictive_fit', default=True, help='extrapolate best fit nuisance parameters based on previous fit results')
-@click.option('--do_better_bands/--skip_better_bands', default=True, help='evaluate asymptotic CLs limit for various sigma bands')
-@click.option('--better_negative_bands/--skip_better_negative_bands', default=False, 
+@click.option('-i', '--input_file', 'filename', required=True, 
+              help='Path to the input workspace file')
+@click.option('-p', '--poi', 'poi_name', default=None, show_default=True,
+              help='POI to scan. If not specified, the first POI from the workspace is used.')
+@click.option('-d', '--data', 'data_name', default='combData', show_default=True,
+              help='Name of dataset')
+@click.option('-o', '--outname', default='limits.json', show_default=True,
+              help='Name of output')
+@click.option('--blind/--unblind', 'do_blind', default=True, show_default=True,
+              help='Blind/unblind analysis')
+@click.option('--CL', 'CL', default=0.95, show_default=True,
+              help='CL value to use')
+@click.option('--precision', default=0.005, show_default=True,
+              help='precision in mu that defines iterative cutoff')
+@click.option('--do_tilde/--no_tilde', default=True, show_default=True,
+              help='bound mu at zero if true and do the \tilde{q}_{mu} asymptotics')
+@click.option('--predictive_fit/--no_predictive_fit', default=True, show_default=True,
+              help='extrapolate best fit nuisance parameters based on previous fit results')
+@click.option('--do_better_bands/--skip_better_bands', default=True, show_default=True,
+              help='evaluate asymptotic CLs limit for various sigma bands')
+@click.option('--better_negative_bands/--skip_better_negative_bands', default=False, show_default=True,
               help='evaluate asymptotic CLs limit for negative sigma bands')
-@click.option('--binned/--unbinned', 'binned_likelihood', default=True, help='Binned likelihood')
-@click.option('--save_summary/--skip_summary', default=True, help='Save summary information')
-@click.option('-f', '--fix', 'fix_param', default="", help='Parameters to fix')
-@click.option('-r', '--profile', 'profile_param', default="", help='Parameters to profile')
-@click.option('-w', '--workspace', 'ws_name', default=None, help='Name of workspace. Auto-detect by default.')
-@click.option('-m', '--model_config', 'mc_name', default=None, help='Name of model config. Auto-detect by default.')
-@click.option('-s', '--snapshot', 'snapshot_name', default=None, help='Name of initial snapshot')
-@click.option('-t', '--minimizer_type', default="Minuit2", help='Minimizer type')
-@click.option('-a', '--minimizer_algo', default="Migrad", help='Minimizer algorithm')
-@click.option('-e', '--eps', type=float, default=1.0, help='Convergence criterium')
-@click.option('--strategy', type=int, default=1, help='Default minimization strategy')
-@click.option('--print_level', type=int, default=-1, help='Minimizer print level')
-@click.option('--timer/--no_timer', default=False, help='Enable minimizer timer')
-@click.option('-c', '--num_cpu', type=int, default=1, help='Number of CPUs to use per parameter')
-@click.option('--offset/--no-offset', default=True, help='Offset likelihood')
-@click.option('--optimize', type=int, default=2, help='Optimize constant terms')
-@click.option('--fix-cache/--no-fix-cache', default=True, help='Fix StarMomentMorph cache')
-@click.option('--fix-multi/--no-fix-cache',  default=True, help='Fix MultiPdf level 2')
-@click.option('--max_calls', type=int, default=-1, help='Maximum number of function calls')
-@click.option('--max_iters', type=int, default=-1, help='Maximum number of Minuit iterations')
-@click.option('--batch_mode/--no-batch', default=False, help='Batch mode when evaluating likelihood')
-@click.option('--int_bin_precision', type=float, default=-1., help='Integrate the PDF over the bins '
-                                                                   'instead of using the probability '
-                                                                   'density at the bin centre')
-@click.option('--constrain/--no-constrain', 'constrain_nuis', default=True, help='Use constrained NLL')
-@click.option('-v', '--verbosity',  default="INFO", help='verbosity level ("DEBUG", "INFO", "WARNING", "ERROR")')
+@click.option('--binned/--unbinned', 'binned_likelihood', default=True, show_default=True,
+              help='Binned likelihood')
+@click.option('--save_summary/--skip_summary', default=True, show_default=True,
+              help='Save summary information')
+@click.option('-f', '--fix', 'fix_param', default="", show_default=True,
+              help='Parameters to fix')
+@click.option('-r', '--profile', 'profile_param', default="", show_default=True,
+              help='Parameters to profile')
+@click.option('-w', '--workspace', 'ws_name', default=None, show_default=True,
+              help='Name of workspace. Auto-detect by default.')
+@click.option('-m', '--model_config', 'mc_name', default=None, show_default=True,
+              help='Name of model config. Auto-detect by default.')
+@click.option('-s', '--snapshot', 'snapshot_name', default=None, show_default=True,
+              help='Name of initial snapshot')
+@click.option('-t', '--minimizer_type', default="Minuit2", show_default=True,
+              help='Minimizer type')
+@click.option('-a', '--minimizer_algo', default="Migrad", show_default=True,
+              help='Minimizer algorithm')
+@click.option('-e', '--eps', type=float, default=1.0, show_default=True,
+              help='Convergence criterium')
+@click.option('--strategy', type=int, default=1, show_default=True,
+              help='Default minimization strategy')
+@click.option('--print_level', type=int, default=-1, show_default=True,
+              help='Minimizer print level')
+@click.option('--timer/--no_timer', default=False, show_default=True,
+              help='Enable minimizer timer')
+@click.option('-c', '--num_cpu', type=int, default=1, show_default=True,
+              help='Number of CPUs to use per parameter')
+@click.option('--offset/--no-offset', default=True, show_default=True,
+              help='Offset likelihood')
+@click.option('--optimize', type=int, default=2, show_default=True,
+              help='Optimize constant terms')
+@click.option('--fix-cache/--no-fix-cache', default=True, show_default=True,
+              help='Fix StarMomentMorph cache')
+@click.option('--fix-multi/--no-fix-cache',  default=True, show_default=True,
+              help='Fix MultiPdf level 2')
+@click.option('--max_calls', type=int, default=-1, show_default=True,
+              help='Maximum number of function calls')
+@click.option('--max_iters', type=int, default=-1, show_default=True,
+              help='Maximum number of Minuit iterations')
+@click.option('--batch_mode/--no-batch', default=False, show_default=True,
+              help='Batch mode when evaluating likelihood')
+@click.option('--int_bin_precision', type=float, default=-1., show_default=True,
+              help='Integrate the PDF over the bins instead of using the probability '
+                   'density at the bin centre')
+@click.option('--constrain/--no-constrain', 'constrain_nuis', default=True, show_default=True,
+              help='Use constrained NLL')
+@click.option('-v', '--verbosity',  default="INFO", show_default=True,
+              help='verbosity level ("DEBUG", "INFO", "WARNING", "ERROR")')
 def cls_limit(**kwargs):
     """
     Tool for evaluating Asymptotic CLs limit
@@ -209,7 +267,8 @@ def cls_limit(**kwargs):
     asymptotic_cls.save(outname, summary=save_summary)
 
 @click.command(name='compile')
-@click.option('-m', '--macros', default=None, help='Macros to compile (separated by commas)')
+@click.option('-m', '--macros', default=None, show_default=True,
+              help='Macros to compile (separated by commas). By default all macros are compiled.')
 def compile_macros(macros):
     """
     Compile ROOT macros
@@ -220,9 +279,12 @@ def compile_macros(macros):
 @click.command(name='harmonize_np')
 @click.argument('ws_files', nargs=-1)
 @click.option('-r', '--reference', required=True, help='Path to reference json file containing renaming scheme')
-@click.option('-i', '--input_config_path', default=None, help='Path to json file containing input workspace paths')
-@click.option('-b', '--base_path', default='./', help='Base path for input config')
-@click.option('-o', '--outfile', default='renamed_np.json', help='Output filename')
+@click.option('-i', '--input_config_path', default=None, show_default=True,
+              help='Path to json file containing input workspace paths')
+@click.option('-b', '--base_path', default='./', show_default=True,
+              help='Base path for input config')
+@click.option('-o', '--outfile', default='renamed_np.json', show_default=True,
+              help='Output filename')
 def harmonize_np(ws_files, reference, input_config_path, base_path, outfile):
     """
     Harmonize NP names across different workspaces
@@ -238,15 +300,18 @@ def harmonize_np(ws_files, reference, input_config_path, base_path, outfile):
         
         
 @click.command(name='generate_asimov')
-@click.option('-i', '--input_file', required=True, help='Path to the input workspace file.')
-@click.option('-o', '--output_file', required=True, help='Name of the output workspace containing the '
-                                                         'generated asimov dataset.')
-@click.option('-p', '--poi', required=True, help='Name of the parameter of interest (POI).')
-@click.option('--poi_val', type=float, default=None,
+@click.option('-i', '--input_file', required=True, 
+              help='Path to the input workspace file.')
+@click.option('-o', '--output_file', required=True, 
+              help='Name of the output workspace containing the '
+                   'generated asimov dataset.')
+@click.option('-p', '--poi', required=True, 
+              help='Name of the parameter of interest (POI).')
+@click.option('--poi_val', type=float, default=None, show_default=True,
               help='Generate asimov data with POI set at the specified value. '
                    'If None, POI will be kept at the post-fit value if a fitting '
                    'is performed or the pre-fit value if no fitting is performed.')
-@click.option('--poi_profile', type=float, default=None,
+@click.option('--poi_profile', type=float, default=None, show_default=True,
               help='Perform nuisance parameter profiling with POI set at the specified value. '
                    'This option is only effective if do_fit is set to True. If None, POI is '
                    'set floating (i.e. unconditional maximum likelihood estimate).')
@@ -301,6 +366,12 @@ def generate_asimov(**kwargs):
               help='Name of the parameter of interest (POI).')
 @click.option('-s', '--poi_scale', type=float, default=1.0, show_default=True,
               help='Scale factor applied to the poi value')
+@click.option('-f', '--fix', 'fix_param', default="", show_default=True,
+              help='Parameters to fix')
+@click.option('-r', '--profile', 'profile_param', default="", show_default=True,
+              help='Parameters to profile')
+@click.option('-s', '--snapshot', 'snapshot_name', default=None, show_default=True,
+              help='Name of initial snapshot')
 @click.option('-t', '--asimov_types', default="0,1,2", show_default=True,
               help='\b\nTypes of asimov dataset to generate separated by commas.\n'
                    '\b 0: fit with POI fixed to 0\n'
@@ -319,7 +390,15 @@ def generate_standard_asimov(**kwargs):
     outname = kwargs.pop('outname')
     asimov_types = kwargs.pop('asimov_types')
     asimov_types = [int(t) for t in asimov_types.split(',')]
-    generator = AsimovGenerator(**kwargs)
+    fix_param = kwargs.pop('fix_param')
+    profile_param = kwargs.pop('profile_param')
+    snapshot_name = kwargs.pop('snapshot_name')
+    config = {
+        'fix_param': fix_param,
+        'profile_param': profile_param,
+        'snapshot_name': snapshot_name
+    }
+    generator = AsimovGenerator(**kwargs, config=config)
     generator.generate(asimov_types)
     generator.save(outname)
     
