@@ -22,11 +22,12 @@ class AnalysisObject(AbstractObject):
         
         if filename is not None:
             self.setup_model(filename, data_name, binned_likelihood, ws_name, mc_name, 
-                             snapshot_name, fix_cache, fix_multi)
+                             snapshot_name, fix_cache, fix_multi, verbosity=verbosity)
             self.setup_parameters(fix_param, profile_param)
             self.setup_minimizer(minimizer_type, minimizer_algo, precision, eps, strategy, num_cpu,
                                  offset, optimize, eigen, max_calls, max_iters, print_level,
-                                 timer, constrain_nuis, batch_mode, int_bin_precision)
+                                 timer, constrain_nuis, batch_mode, int_bin_precision,
+                                 verbosity=verbosity)
         
     def setup_model(self, filename, data_name='combData', binned_likelihood:bool=True, 
                     ws_name:Optional[str]=None, mc_name:Optional[str]=None, 
